@@ -105,6 +105,7 @@ public:
     // file actions
     void file_new();
     void file_open();
+    void folder_open();
     void file_save();
     void file_vacuum();
     void file_save_as();
@@ -481,6 +482,7 @@ public:
     void import_node_from_plaintext_file() noexcept;
     void import_nodes_from_plaintext_directory() noexcept;
     void import_nodes_from_ct_file() noexcept;
+    void import_nodes_from_ct_folder() noexcept;
     void import_nodes_from_zim_directory() noexcept;
     void import_node_from_md_file() noexcept;
     void import_nodes_from_md_directory() noexcept;
@@ -488,6 +490,7 @@ public:
     void import_nodes_from_tomboy_directory() noexcept;
     void import_nodes_from_keepnote_directory() noexcept;
     void import_nodes_from_mempad_file() noexcept;
+    void import_nodes_from_indented_list_file() noexcept;
     void import_nodes_from_treepad_file() noexcept;
     void import_nodes_from_leo_file() noexcept;
     void import_nodes_from_rednotebook_html() noexcept;
@@ -510,7 +513,7 @@ public:
     void export_to_pdf();
     void export_to_html();
     void export_to_txt();
-    void export_to_ctd();
+    void export_to_ct();
 
     void export_to_pdf_auto(const std::string& dir, bool overwrite);
     void export_to_html_auto(const std::string& dir, bool overwrite, bool single_file);
