@@ -170,7 +170,11 @@ void CtConfig::_populate_current_group_from_map(const std::map<std::string, std:
 
 void CtConfig::_unexpected_keyfile_error(const gchar* key, const Glib::KeyFileError& kferror)
 {
+#if defined(FMT_VERSION) && FMT_VERSION >= 100000
+    spdlog::error("!! {} error code {} ", key, fmt::underlying(kferror.code()));
+#else // FMT_VERSION < 10.0.0
     spdlog::error("!! {} error code {} ", key, kferror.code());
+#endif // FMT_VERSION < 10.0.0
 }
 
 void CtConfig::_populate_keyfile_from_data()
@@ -231,6 +235,7 @@ void CtConfig::_populate_keyfile_from_data()
     _uKeyFile->set_string(_currentGroup, "nodes_icons", nodesIcons);
     _uKeyFile->set_boolean(_currentGroup, "aux_icon_hide", auxIconHide);
     _uKeyFile->set_integer(_currentGroup, "default_icon_text", defaultIconText);
+    _uKeyFile->set_integer(_currentGroup, "last_icon_sel", lastIconSel);
     _uKeyFile->set_boolean(_currentGroup, "tree_right_side", treeRightSide);
     _uKeyFile->set_boolean(_currentGroup, "cherry_wrap_ena", cherryWrapEnabled);
     _uKeyFile->set_integer(_currentGroup, "cherry_wrap_width", cherryWrapWidth);
@@ -518,6 +523,7 @@ void CtConfig::_populate_data_from_keyfile()
     _populate_string_from_keyfile("nodes_icons", &nodesIcons);
     _populate_bool_from_keyfile("aux_icon_hide", &auxIconHide);
     _populate_int_from_keyfile("default_icon_text", &defaultIconText);
+    _populate_int_from_keyfile("last_icon_sel", &lastIconSel);
     _populate_bool_from_keyfile("tree_right_side", &treeRightSide);
     _populate_bool_from_keyfile("cherry_wrap_ena", &cherryWrapEnabled);
     _populate_int_from_keyfile("cherry_wrap_width", &cherryWrapWidth);
