@@ -1,7 +1,7 @@
 /*
  * ct_config.h
  *
- * Copyright 2009-2022
+ * Copyright 2009-2023
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -60,7 +60,9 @@ public:
     bool                                        winIsMaximised{false};
     int                                         winRect[4]{10, 10, 963, 630};
     int                                         hpanedPos{170};
+    int                                         vpanedPos{450};
     bool                                        treeVisible{true};
+    bool                                        vteVisible{false};
     bool                                        menubarVisible{true};
     CtRecentDocsFilepaths                       recentDocsFilepaths;
     std::string                                 pickDirImport;
@@ -82,6 +84,7 @@ public:
     std::string                                 nodesIcons{CtConst::NODE_ICON_TYPE_CHERRY};
     bool                                        auxIconHide{false};
     int                                         defaultIconText{CtConst::NODE_ICON_BULLET_ID};
+    int                                         lastIconSel{CtConst::NODE_ICON_SEL_DEFAULT};
     bool                                        treeRightSide{false};
     bool                                        cherryWrapEnabled{false};
     int                                         cherryWrapWidth{130};
@@ -90,7 +93,7 @@ public:
 
     // [editor]
     std::string                                 syntaxHighlighting{CtConst::RICH_TEXT_ID};
-    std::string                                 autoSynHighl{CtConst::SYN_HIGHL_BASH};
+    std::string                                 autoSynHighl{CtConst::SYN_HIGHL_SHELL};
     std::string                                 rtStyleScheme{"user-1"};
     std::string                                 ptStyleScheme{"user-1"};
     std::string                                 taStyleScheme{"user-2"};
@@ -118,6 +121,8 @@ public:
     int                                         wrappingIndent{-14};
     bool                                        autoIndent{true};
     bool                                        codeExecConfirm{true};
+    bool                                        codeExecVte{true};
+    std::string                                 vteShell{CtConst::VTE_SHELL_DEFAULT};
     bool                                        rtShowWhiteSpaces{false};
     bool                                        ptShowWhiteSpaces{true};
     bool                                        rtHighlCurrLine{true};
@@ -169,12 +174,14 @@ public:
     int                                         tableRows{3};
     int                                         tableColumns{3};
     int                                         tableColWidthDefault{60};
+    int                                         tableCellsGoLight{CtConst::ADVISED_TABLE_LIGHT_HEAVY};
 
     // [fonts]
     Glib::ustring                               rtFont{CtConst::FONT_RT_DEFAULT};
     Glib::ustring                               ptFont{CtConst::FONT_PT_DEFAULT};
     Glib::ustring                               treeFont{CtConst::FONT_TREE_DEFAULT};
     Glib::ustring                               codeFont{CtConst::FONT_CODE_DEFAULT};
+    Glib::ustring                               vteFont{CtConst::FONT_VTE_DEFAULT};
     Glib::ustring                               fallbackFontFamily{"Sans"};
 
     // [colors]
@@ -226,7 +233,6 @@ public:
     bool                                        customBackupDirOn{false};
     std::string                                 customBackupDir{""};
     int                                         limitUndoableSteps{10};
-    bool                                        usePandoc{true}; // Whether to use Pandoc for exporting
 
     // [keyboard]
     std::map<std::string, std::string>          customKbShortcuts;
