@@ -34,14 +34,15 @@ struct CtConst {
 const inline static gchar* CT_VERSION  {PACKAGE_VERSION};
 const inline static gchar* APP_NAME    {PACKAGE_NAME};
 
-const inline static gchar* CTDOC_XML_NOENC          {".ctd"};
-const inline static gchar* CTDOC_XML_ENC            {".ctz"};
-const inline static gchar* CTDOC_SQLITE_NOENC       {".ctb"};
-const inline static gchar* CTDOC_SQLITE_ENC         {".ctx"};
-const inline static gchar* LINK_TYPE_WEBS           {"webs"};
-const inline static gchar* LINK_TYPE_FILE           {"file"};
-const inline static gchar* LINK_TYPE_FOLD           {"fold"};
-const inline static gchar* LINK_TYPE_NODE           {"node"};
+const inline static std::string CTDOC_XML_NOENC     {".ctd"};
+const inline static std::string CTDOC_XML_ENC       {".ctz"};
+const inline static std::string CTDOC_SQLITE_NOENC  {".ctb"};
+const inline static std::string CTDOC_SQLITE_ENC    {".ctx"};
+
+const inline static std::string LINK_TYPE_WEBS      {"webs"};
+const inline static std::string LINK_TYPE_FILE      {"file"};
+const inline static std::string LINK_TYPE_FOLD      {"fold"};
+const inline static std::string LINK_TYPE_NODE      {"node"};
 const inline static gchar* NODE_ICON_TYPE_CHERRY    {"c"};
 const inline static gchar* NODE_ICON_TYPE_CUSTOM    {"b"};
 const inline static gchar* NODE_ICON_TYPE_NONE      {"n"};
@@ -178,37 +179,38 @@ const inline static int INDENT_MARGIN                  {50};
 const inline static int TREE_DRAG_EDGE_PROX            {10};
 const inline static int TREE_DRAG_EDGE_SCROLL          {15};
 
-const inline static gchar* CHAR_SPACE             {" "};
-const inline static gchar* CHAR_NEWLINE           {"\n"};
-const inline static gchar* CHAR_NEWPAGE           {"\x0c"};
-const inline static gchar* CHAR_CR                {"\r"};
-const inline static gchar* CHAR_TAB               {"\t"};
+const inline static std::string CHAR_SPACE          {" "};
+const inline static std::string CHAR_NEWLINE        {"\n"};
+const inline static std::string CHAR_NEWPAGE        {"\x0c"};
+const inline static std::string CHAR_CR             {"\r"};
+const inline static std::string CHAR_TAB            {"\t"};
 const inline static std::array<gunichar, 4> CHARS_LISTNUM {'.', ')', '-', '>'};
-const inline static gchar* CHAR_TILDE             {"~"};
-const inline static gchar* CHAR_MINUS             {"-"};
-const inline static gchar* CHAR_DQUOTE            {"\""};
-const inline static gchar* CHAR_SQUOTE            {"'"};
-const inline static gchar* CHAR_GRAVE             {"`"};
-const inline static gchar* CHAR_SLASH             {"/"};
-const inline static gchar* CHAR_BSLASH            {"\\"};
-const inline static gchar* CHAR_SQ_BR_OPEN        {"["};
-const inline static gchar* CHAR_SQ_BR_CLOSE       {"]"};
-const inline static gchar* CHAR_PARENTH_OPEN      {"("};
-const inline static gchar* CHAR_PARENTH_CLOSE     {")"};
-const inline static gchar* CHAR_LESSER            {"<"};
-const inline static gchar* CHAR_GREATER           {">"};
-const inline static gchar* CHAR_STAR              {"*"};
-const inline static gchar* CHAR_QUESTION          {"?"};
-const inline static gchar* CHAR_COMMA             {","};
-const inline static gchar* CHAR_COLON             {":"};
-const inline static gchar* CHAR_SEMICOLON         {";"};
-const inline static gchar* CHAR_USCORE            {"_"};
-const inline static gchar* CHAR_EQUAL             {"="};
-const inline static gchar* CHAR_BR_OPEN           {"{"};
-const inline static gchar* CHAR_BR_CLOSE          {"}"};
-const inline static gchar* CHAR_CARET             {"^"};
-const inline static gchar* CHAR_PIPE              {"|"};
-const inline static gchar* CHAR_AMPERSAND         {"&"};
+const inline static std::string CHAR_DOT            {"."};
+const inline static std::string CHAR_TILDE          {"~"};
+const inline static std::string CHAR_MINUS          {"-"};
+const inline static std::string CHAR_DQUOTE         {"\""};
+const inline static std::string CHAR_SQUOTE         {"'"};
+const inline static std::string CHAR_GRAVE          {"`"};
+const inline static std::string CHAR_SLASH          {"/"};
+const inline static std::string CHAR_BSLASH         {"\\"};
+const inline static std::string CHAR_SQ_BR_OPEN     {"["};
+const inline static std::string CHAR_SQ_BR_CLOSE    {"]"};
+const inline static std::string CHAR_PARENTH_OPEN   {"("};
+const inline static std::string CHAR_PARENTH_CLOSE  {")"};
+const inline static std::string CHAR_LESSER         {"<"};
+const inline static std::string CHAR_GREATER        {">"};
+const inline static std::string CHAR_STAR           {"*"};
+const inline static std::string CHAR_QUESTION       {"?"};
+const inline static std::string CHAR_COMMA          {","};
+const inline static std::string CHAR_COLON          {":"};
+const inline static std::string CHAR_SEMICOLON      {";"};
+const inline static std::string CHAR_USCORE         {"_"};
+const inline static std::string CHAR_EQUAL          {"="};
+const inline static std::string CHAR_BR_OPEN        {"{"};
+const inline static std::string CHAR_BR_CLOSE       {"}"};
+const inline static std::string CHAR_CARET          {"^"};
+const inline static std::string CHAR_PIPE           {"|"};
+const inline static std::string CHAR_AMPERSAND      {"&"};
 
 const inline static std::array<std::string_view, 4> WEB_LINK_STARTERS {
     "http://",
@@ -243,7 +245,7 @@ const inline static std::array<const gchar*, 4> TAG_ALIGNMENTS {
 const inline static gchar* TOOLBAR_SPLIT {"toolbar_split"};
 const inline static gchar* TOOLBAR_VEC_DEFAULT {
     "tree_add_node,tree_add_subnode,separator,go_node_prev,go_node_next,"
-    "separator,*,ct_save,export_pdf,separator,"
+    "separator,ct_open_folder,*,ct_save,export_pdf,separator,"
     "find_in_allnodes,separator,handle_bull_list,handle_num_list,handle_todo_list,fmt_indent,fmt_unindent,"
     "separator,handle_image,handle_table,handle_codebox,handle_latex,handle_embfile,"
     "handle_link,handle_anchor,separator,fmt_clone,fmt_latest,fmt_rm,fmt_color_fg,"
@@ -261,160 +263,217 @@ const inline static std::vector<const gchar*> AVAILABLE_LANGS {
 const inline static int NODE_ICON_CODE_ID          {38};
 const inline static int NODE_ICON_BULLET_ID        {25};
 const inline static int NODE_ICON_NO_ICON_ID       {26};
+const inline static int NODE_ICON_SEL_DEFAULT     {132};
 const inline static int NODE_ICON_SIZE             {16};
 const inline static int MAX_TOOLTIP_LINK_CHARS     {150};
 const inline static int ADVISED_TABLE_LIGHT_HEAVY  {25};
 
-const inline static std::vector<const gchar*> NODE_CUSTOM_ICONS {
-    nullptr,            // NEVER USED
-    "ct_circle-green",  //  1
-    "ct_circle-yellow", //  2
-    "ct_circle-red",    //  3
-    "ct_circle-grey",   //  4
-    "ct_add",           //  5
-    "ct_remove",        //  6
-    "ct_done",          //  7
-    "ct_cancel",        //  8
-    "ct_edit_delete",   //  9
-    "ct_warning",       // 10
-    "ct_star",          // 11
-    "ct_info",          // 12
-    "ct_help",          // 13
-    "ct_home",          // 14
-    "ct_index",         // 15
-    "ct_mail",          // 16
-    "ct_html",          // 17
-    "ct_notes",         // 18
-    "ct_timestamp",     // 19
-    "ct_calendar",      // 20
-    "ct_term",          // 21
-    "ct_term-red",      // 22
-    "ct_python",        // 23
-    "ct_java",          // 24
-    "ct_node_bullet",   // 25
-    "ct_node_no_icon",  // 26
-    CHERRY_BLACK,       // 27
-    CHERRY_BLUE,        // 28
-    CHERRY_CYAN,        // 29
-    CHERRY_GREEN,       // 30
-    CHERRY_GRAY,        // 31
-    CHERRY_ORANGE,      // 32
-    CHERRY_ORANGE_DARK, // 33
-    CHERRY_PURPLE,      // 34
-    CHERRY_RED,         // 35
-    CHERRY_SHERBERT,    // 36
-    CHERRY_YELLOW,      // 37
-    "ct_code",          // 38
-    "ct_find",          // 39
-    "ct_locked",        // 40
-    "ct_unlocked",      // 41
-    "ct_people",        // 42
-    "ct_urgent",        // 43
-    "ct_directory",     // 44
-    "ct_leaf",          // 45
-    "ct_xml",           // 46
-    "ct_c",             // 47
-    "ct_cpp",           // 48
-    "ct_perl",          // 49
-    "ct_pin",           // 50
-    "ct_anchor",        // 51
-    "ct_edit",          // 52
-    "ct_save",          // 53
-    "ct_execute",       // 54
-    "ct_preferences",   // 55
-    "ct_clear",         // 56
-    "ct_stop",          // 57
-    "ct_close",         // 58
-    "ct_quit-app",      // 59
-    "ct_file",          // 60
-    "ct_print",         // 61
-    "ct_file_icon",     // 62
-    "ct_link_handle",   // 63
-    "ct_link_website",  // 64
-    "ct_network",       // 65
-    "ct_go-back",       // 66
-    "ct_go-down",       // 67
-    "ct_go-forward",    // 68
-    "ct_go-up",         // 69
-    "ct_go-jump",       // 70
-    "ct_zoom-out",      // 71
-    "ct_zoom-in",       // 72
-    "ct_bg",            // 73
-    "ct_cs",            // 74
-    "ct_de",            // 75
-    "ct_el",            // 76
-    "ct_en",            // 77
-    "ct_en_US",         // 78
-    "ct_es",            // 79
-    "ct_fi",            // 80
-    "ct_fr",            // 81
-    "ct_hy",            // 82
-    "ct_it",            // 83
-    "ct_ja",            // 84
-    "ct_lt",            // 85
-    "ct_nl",            // 86
-    "ct_pl",            // 87
-    "ct_pt_BR",         // 88
-    "ct_ru",            // 89
-    "ct_sl",            // 90
-    "ct_sv",            // 91
-    "ct_tr",            // 92
-    "ct_uk",            // 93
-    "ct_zh_CN",         // 94
-    "ct_sports",        // 95
-    "ct_briefcase",     // 96
-    "ct_camera",        // 97
-    "ct_chart",         // 98
-    "ct_clapperboard",  // 99
-    "ct_maths",        // 100
-    "ct_games",        // 101
-    "ct_globe",        // 102
-    "ct_server",       // 103
-    "ct_money",        // 104
-    "ct_painting",     // 105
-    "ct_puzzle",       // 106
-    "ct_shopping",     // 107
-    "ct_heart",        // 108
-    "ct_smile",        // 109
-    "ct_smile_cool",   // 110
-    "ct_smile_surpr",  // 111
-    "ct_skull",        // 112
-    "ct_no_access",    // 113
-    "ct_ruby",         // 114
-    "ct_tux",          // 115
-    "ct_gnome",        // 116
-    "ct_debian",       // 117
-    "ct_ubuntu",       // 118
-    "ct_freebsd",      // 119
-    "ct_win10",        // 120
-    "ct_win2012",      // 121
-    "ct_ko",           // 122
-    "ct_kk_KZ",        // 123
-    "ct_ro",           // 124
-    "ct_hr",           // 125
-    "ct_ghost",        // 126
-    "ct_pt",           // 127
-    "ct_zh_TW",        // 128
-    "ct_hi_IN",        // 129
-    "ct_ar",           // 130
-    "ct_hu",           // 131
-    "ct_heart_ukraine",// 132
-    "ct_microchip",    // 133
-    "ct_ansible",      // 134
-    "ct_aws",          // 135
-    "ct_azure",        // 136
-    "ct_docker",       // 137
-    "ct_gcp",          // 138
-    "ct_kubernetes",   // 139
-    "ct_csharp",       // 140
+// do not use _NODE_CUSTOM_ICONS directly, use wrapper CtStockIcon instead
+const inline static std::vector<const gchar*> _NODE_CUSTOM_ICONS {
+    nullptr,                // NEVER USED
+    "ct_circle-green",      //  1
+    "ct_circle-yellow",     //  2
+    "ct_circle-red",        //  3
+    "ct_circle-grey",       //  4
+    "ct_add",               //  5
+    "ct_remove",            //  6
+    "ct_done",              //  7
+    "ct_cancel",            //  8
+    "ct_edit_delete",       //  9
+    "ct_warning",           // 10
+    "ct_star",              // 11
+    "ct_info",              // 12
+    "ct_help",              // 13
+    "ct_home",              // 14
+    "ct_index",             // 15
+    "ct_mail",              // 16
+    "ct_html",              // 17
+    "ct_notes",             // 18
+    "ct_timestamp",         // 19
+    "ct_calendar",          // 20
+    "ct_term",              // 21
+    "ct_term-red",          // 22
+    "ct_python",            // 23
+    "ct_java",              // 24
+    "ct_node_bullet",       // 25
+    "ct_node_no_icon",      // 26
+    CHERRY_BLACK,           // 27
+    CHERRY_BLUE,            // 28
+    CHERRY_CYAN,            // 29
+    CHERRY_GREEN,           // 30
+    CHERRY_GRAY,            // 31
+    CHERRY_ORANGE,          // 32
+    CHERRY_ORANGE_DARK,     // 33
+    CHERRY_PURPLE,          // 34
+    CHERRY_RED,             // 35
+    CHERRY_SHERBERT,        // 36
+    CHERRY_YELLOW,          // 37
+    "ct_code",              // 38
+    "ct_find",              // 39
+    "ct_locked",            // 40
+    "ct_unlocked",          // 41
+    "ct_people",            // 42
+    "ct_urgent",            // 43
+    "ct_directory",         // 44
+    "ct_leaf",              // 45
+    "ct_xml",               // 46
+    "ct_c",                 // 47
+    "ct_cpp",               // 48
+    "ct_perl",              // 49
+    "ct_pin",               // 50
+    "ct_anchor",            // 51
+    "ct_edit",              // 52
+    "ct_save",              // 53
+    "ct_execute",           // 54
+    "ct_preferences",       // 55
+    "ct_clear",             // 56
+    "ct_stop",              // 57
+    "ct_close",             // 58
+    "ct_quit-app",          // 59
+    "ct_file",              // 60
+    "ct_print",             // 61
+    "ct_file_icon",         // 62
+    "ct_link_handle",       // 63
+    "ct_link_website",      // 64
+    "ct_network",           // 65
+    "ct_go-back",           // 66
+    "ct_go-down",           // 67
+    "ct_go-forward",        // 68
+    "ct_go-up",             // 69
+    "ct_go-jump",           // 70
+    "ct_zoom-out",          // 71
+    "ct_zoom-in",           // 72
+    "ct_bg",                // 73
+    "ct_cs",                // 74
+    "ct_de",                // 75
+    "ct_el",                // 76
+    "ct_en",                // 77
+    "ct_en_US",             // 78
+    "ct_es",                // 79
+    "ct_fi",                // 80
+    "ct_fr",                // 81
+    "ct_hy",                // 82
+    "ct_it",                // 83
+    "ct_ja",                // 84
+    "ct_lt",                // 85
+    "ct_nl",                // 86
+    "ct_pl",                // 87
+    "ct_pt_BR",             // 88
+    "ct_ru",                // 89
+    "ct_sl",                // 90
+    "ct_sv",                // 91
+    "ct_tr",                // 92
+    "ct_uk",                // 93
+    "ct_zh_CN",             // 94
+    "ct_sports",            // 95
+    "ct_briefcase",         // 96
+    "ct_camera",            // 97
+    "ct_chart",             // 98
+    "ct_clapperboard",      // 99
+    "ct_maths",             // 100
+    "ct_games",             // 101
+    "ct_globe",             // 102
+    "ct_server",            // 103
+    "ct_money",             // 104
+    "ct_painting",          // 105
+    "ct_puzzle",            // 106
+    "ct_shopping",          // 107
+    "ct_heart",             // 108
+    "ct_smile",             // 109
+    "ct_smile_cool",        // 110
+    "ct_smile_surpr",       // 111
+    "ct_skull",             // 112
+    "ct_no_access",         // 113
+    "ct_ruby",              // 114
+    "ct_tux",               // 115
+    "ct_gnome",             // 116
+    "ct_debian",            // 117
+    "ct_ubuntu",            // 118
+    "ct_freebsd",           // 119
+    "ct_win10",             // 120
+    "ct_win2012",           // 121
+    "ct_ko",                // 122
+    "ct_kk_KZ",             // 123
+    "ct_ro",                // 124
+    "ct_hr",                // 125
+    "ct_ghost",             // 126
+    "ct_pt",                // 127
+    "ct_zh_TW",             // 128
+    "ct_hi_IN",             // 129
+    "ct_ar",                // 130
+    "ct_hu",                // 131
+    "ct_heart_ukraine",     // 132
+    "ct_microchip",         // 133
+    "ct_ansible",           // 134
+    "ct_aws",               // 135
+    "ct_azure",             // 136
+    "ct_docker",            // 137
+    "ct_gcp",               // 138
+    "ct_kubernetes",        // 139
+    "ct_csharp",            // 140
+    "ct_7zip",              // 141
+    "ct_chat",              // 142
+    "ct_db",                // 143
+    "ct_dictionary",        // 144
+    "ct_invest",            // 145
+    "ct_keys",              // 146
+    "ct_W-cloudy",          // 147
+    "ct_W-few-clouds",      // 148
+    "ct_W-fog",             // 149
+    "ct_W-night-clear",     // 150
+    "ct_W-night-few-clouds",// 151
+    "ct_W-showers",         // 152
+    "ct_W-snow",            // 153
+    "ct_W-storm",           // 154
+    "ct_W-sunny",           // 155
+    "ct_apple",             // 156
+    "ct_bike",              // 157
+    "ct_bluetooth",         // 158
+    "ct_building",          // 159
+    "ct_bus",               // 160
+    "ct_car",               // 161
+    "ct_cellphone",         // 162
+    "ct_cloud",             // 163
+    "ct_computer",          // 164
+    "ct_display",           // 165
+    "ct_drive-harddisk",    // 166
+    "ct_drive-usb",         // 167
+    "ct_female",            // 168
+    "ct_food",              // 169
+    "ct_hamburger",         // 170
+    "ct_lifebuoy",          // 171
+    "ct_linuxmint",         // 172
+    "ct_male",              // 173
+    "ct_pizza",             // 174
+    "ct_telephone",         // 175
+    "ct_wifi",              // 176
+    "ct_antenna",           // 177
 };
 
 const inline static std::vector<int> NODE_CUSTOM_ICONS_ORDERED {
-    132, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 18, 19, 20, 133,
-    /*coding start*/17, 21, 22, 23, 24, 38, 46, 47, 48, 49, 140/*coding end*/,
-    114, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 39, 40, 41, 42, 43, 44, 45, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 126, 113,
-    /*os start*/115, 116, 117, 118, 119, 120, 121/*os end*/,
+    132, /*circle start*/1, 2, 3, 4/*circle end*/,
+    5/*add*/, 6/*remove*/, 7/*done*/, 8/*cancel*/, 9/*delete*/, 10/*warning*/, 43/*urgent*/, 113/*no access*/, 11/*star*/, 12/*info*/,
+    13/*help*/, 171/*lifebuoy*/, 14/*home*/, 15/*index*/, 16/*mail*/, 18/*notes*/, 142/*chat*/, 19/*timestamp*/, 20/*calendar*/,
+    39/*find*/, 40/*locked*/, 41/*unlocked*/, 45/*leaf*/,
+    50/*pin*/, 51/*anchor*/, 52/*edit*/, 53/*save*/, 54/*execute*/, 55/*preferences*/, 56/*clear*/, 57/*stop*/, 58/*close*/, 59/*quit app*/,
+    60/*file*/, 141/*7zip*/, 44/*folder*/, 143/*db*/, 146/*keys*/,
+    61/*print*/, 62/*attachment*/, 63/*link*/, 64/*linkweb*/, 65/*network*/,
+    66/*back*/, 67/*down*/, 68/*forward*/, 69/*up*/, 70/*jump to*/, 71/*zoom out*/, 72/*zoom in*/,
+    95/*sports*/, 96/*briefcase*/, 159/*building*/, 98/*chart*/, 145/*invest*/, 104/*money*/,
+    97/*camera*/, 99/*clapperboard*/, 100/*maths*/, 101/*games*/, 144/*dictionary*/,
+    157/*bike*/, 161/*car*/, 160/*bus*/,
+    169/*food*/, 170/*hamburger*/, 174/*pizza*/,
+    162/*cellphone*/, 175/*telephone*/,
+    102/*globe*/, 103/*server*/, 163/*cloud*/, 176/*wifi*/, 177/*antenna*/, 158/*bluetooth*/,
+    105/*painting*/, 106/*puzzle*/, 107/*shopping*/, 108/*heart*/,
+    168/*female*/, 173/*male*/, 42/*people*/, 109/*smile*/, 110/*smile cool*/, 111/*smile surpr*/, 112/*skull*/, 126/*ghost*/,
+    /*os start*/115, 116, 117, 118, 172, 119, 120, 121, 156/*os end*/,
+    133/*microchip*/, 164/*computer*/, 165/*display*/, 166/*drive hd*/, 167/*drive usb*/,
+    /*coding start*/17, 21, 22, 23, 24, 38, 46, 47, 48, 49, 140, 114/*coding end*/,
     /*devops start*/134, 135, 136, 137, 138, 139/*devops end*/,
+    /*weather start*/147, 148, 149, 150, 151, 152, 153, 154, 155/*weather end*/,
+    /*cherries start*/27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37/*cherries end*/,
+    25/*bullet*/, 26/*noicon*/,
     /*flags start*/73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 122, 123, 124, 125, 127, 128, 129, 130, 131/*flags end*/
 };
 
@@ -434,19 +493,19 @@ const inline static std::array<const gchar*, 11> NODE_CHERRY_ICONS {
 };
 
 const inline static std::vector<std::pair<const gchar*, const gchar*>> NODE_CODE_ICONS {
-    std::make_pair("python", "ct_python"),
-    std::make_pair("python3", "ct_python"),
-    std::make_pair("perl", "ct_perl"),
-    std::make_pair("sh", "ct_term"),
-    std::make_pair("dosbatch", "ct_term-red"),
-    std::make_pair("powershell", "ct_term-red"),
-    std::make_pair("java", "ct_java"),
-    std::make_pair("html", "ct_html"),
-    std::make_pair("xml", "ct_xml"),
-    std::make_pair("c", "ct_c"),
-    std::make_pair("cpp", "ct_cpp"),
-    std::make_pair("c-sharp", "ct_csharp"),
-    std::make_pair("ruby", "ct_ruby")
+    std::make_pair("python",        "ct_python"),
+    std::make_pair("python3",       "ct_python"),
+    std::make_pair("perl",          "ct_perl"),
+    std::make_pair("sh",            "ct_term"),
+    std::make_pair("dosbatch",      "ct_term-red"),
+    std::make_pair("powershell",    "ct_term-red"),
+    std::make_pair("java",          "ct_java"),
+    std::make_pair("html",          "ct_html"),
+    std::make_pair("xml",           "ct_xml"),
+    std::make_pair("c",             "ct_c"),
+    std::make_pair("cpp",           "ct_cpp"),
+    std::make_pair("c-sharp",       "ct_csharp"),
+    std::make_pair("ruby",          "ct_ruby"),
 };
 
 const inline static gchar* CODE_EXEC_TMP_SRC  {"<tmp_src_path>"};
@@ -455,15 +514,16 @@ const inline static gchar* CODE_EXEC_CODE_TXT {"<code_txt>"};
 const inline static gchar* CODE_EXEC_COMMAND  {"<command>"};
 
 const inline static std::vector<std::pair<const std::string, const std::string>> CODE_EXEC_TYPE_CMD_DEFAULT {
-    std::make_pair("c",          std::string("gcc -o ") + CODE_EXEC_TMP_BIN + " " + CODE_EXEC_TMP_SRC + " && " + CODE_EXEC_TMP_BIN),
-    std::make_pair("cpp",        std::string("g++ -o ") + CODE_EXEC_TMP_BIN + " " + CODE_EXEC_TMP_SRC + " && " + CODE_EXEC_TMP_BIN),
-    std::make_pair("dosbatch",   std::string("call ") + CODE_EXEC_TMP_SRC),
-    std::make_pair("perl",       std::string("perl ") + CODE_EXEC_TMP_SRC),
-    std::make_pair("powershell", std::string("powershell -File ") + CODE_EXEC_TMP_SRC),
-    std::make_pair("python",     std::string("python2 ") + CODE_EXEC_TMP_SRC),
-    std::make_pair("python3",    std::string("python3 ") + CODE_EXEC_TMP_SRC),
+    std::make_pair("c",          std::string{"gcc -o "} + CODE_EXEC_TMP_BIN + " " + CODE_EXEC_TMP_SRC + " && " + CODE_EXEC_TMP_BIN),
+    std::make_pair("cpp",        std::string{"g++ -o "} + CODE_EXEC_TMP_BIN + " " + CODE_EXEC_TMP_SRC + " && " + CODE_EXEC_TMP_BIN),
+    std::make_pair("dosbatch",   std::string{"call "} + CODE_EXEC_TMP_SRC),
+    std::make_pair("perl",       std::string{"perl "} + CODE_EXEC_TMP_SRC),
+    std::make_pair("powershell", std::string{"powershell -File "} + CODE_EXEC_TMP_SRC),
+    std::make_pair("python",     std::string{"python2 "} + CODE_EXEC_TMP_SRC),
+    std::make_pair("python3",    std::string{"python3 "} + CODE_EXEC_TMP_SRC),
     std::make_pair("sh",         CODE_EXEC_CODE_TXT),
-    std::make_pair("c-sharp",    std::string("csc /out:") + CODE_EXEC_TMP_BIN + " " + CODE_EXEC_TMP_SRC + " && " + CODE_EXEC_TMP_BIN)
+    std::make_pair("c-sharp",    std::string{"csc /out:"} + CODE_EXEC_TMP_BIN + " " + CODE_EXEC_TMP_SRC + " && " + CODE_EXEC_TMP_BIN),
+    std::make_pair("java",       std::string{"java "} + CODE_EXEC_TMP_SRC),
 };
 
 const inline static std::vector<std::pair<const std::string, const std::string>> CODE_EXEC_TYPE_EXT_DEFAULT {
@@ -475,7 +535,8 @@ const inline static std::vector<std::pair<const std::string, const std::string>>
     std::make_pair("python",     "py"),
     std::make_pair("python3",    "py"),
     std::make_pair("sh",         "sh"),
-    std::make_pair("c-sharp",    "cs")
+    std::make_pair("c-sharp",    "cs"),
+    std::make_pair("java",       "java"),
 };
 
 const inline static std::unordered_map<std::string, std::string> CODE_EXEC_TERM_RUN_DEFAULT {
