@@ -207,35 +207,51 @@ void CtDialogs::bookmarks_handle_dialog(CtMainWin* pCtMainWin)
     pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::book);
 }
 
-// Choose the CherryTree data storage type (xml or db) and protection
-bool CtDialogs::choose_data_storage_dialog(storage_select_args& args)
+// Choose the CherryTree data storage type and protection
+bool CtDialogs::choose_data_storage_dialog(CtMainWin* pCtMainWin, CtStorageSelectArgs& args)
 {
     Gtk::Dialog dialog{_("Choose Storage Type"),
-                       *args.pCtMainWin,
+                       *pCtMainWin,
                        Gtk::DialogFlags::DIALOG_MODAL | Gtk::DialogFlags::DIALOG_DESTROY_WITH_PARENT};
     Gtk::Button* pButtonCancel = dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_REJECT);
     Gtk::Button* pButtonOk = dialog.add_button(Gtk::Stock::OK, Gtk::RESPONSE_ACCEPT);
     dialog.set_default_size(350, -1);
     dialog.set_position(Gtk::WIN_POS_CENTER_ON_PARENT);
 
-    Glib::ustring labelPrefixSQLite{"SQLite, "};
-    Glib::ustring labelPrefixXML{"XML, "};
-    Gtk::RadioButton radiobutton_sqlite_not_protected(labelPrefixSQLite + _("Not Protected") + " (.ctb)");
+    Gtk::RadioButton radiobutton_sqlite_not_protected(Glib::ustring{"Single SQLite File"} + " (.ctb)");
     Gtk::RadioButton::Group rbGroup = radiobutton_sqlite_not_protected.get_group();
-    Gtk::RadioButton radiobutton_sqlite_pass_protected(rbGroup, labelPrefixSQLite + _("Password Protected") + " (.ctx)");
-    Gtk::RadioButton radiobutton_xml_not_protected(rbGroup, labelPrefixXML + _("Not Protected") + " (.ctd)");
-    Gtk::RadioButton radiobutton_xml_pass_protected(rbGroup, labelPrefixXML + _("Password Protected") + " (.ctz)");
+    Gtk::RadioButton radiobutton_sqlite_pass_protected(rbGroup, Glib::ustring{"Single SQLite File, 7-zip Encrypted and Password Protected"} + " (.ctx)");
+    Gtk::RadioButton radiobutton_xml_not_protected(rbGroup, Glib::ustring{"Single XML File"}  + " (.ctd)");
+    Gtk::RadioButton radiobutton_xml_pass_protected(rbGroup, Glib::ustring{"Single XML File, 7-zip Encrypted and Password Protected"} + " (.ctz)");
+    Gtk::RadioButton radiobutton_multifile(rbGroup, Glib::ustring{"Multiple Files in Hierarchical Folder Structure"});
 
-    Gtk::VBox type_vbox;
-    type_vbox.pack_start(radiobutton_sqlite_not_protected);
-    type_vbox.pack_start(radiobutton_sqlite_pass_protected);
-    type_vbox.pack_start(radiobutton_xml_not_protected);
-    type_vbox.pack_start(radiobutton_xml_pass_protected);
+    Gtk::Image* image_sqlite_not_protected = pCtMainWin->new_managed_image_from_stock("ct_db", Gtk::ICON_SIZE_MENU);
+    Gtk::Image* image_sqlite_pass_protected = pCtMainWin->new_managed_image_from_stock("ct_7zip", Gtk::ICON_SIZE_MENU);
+    Gtk::Image* image_xml_not_protected = pCtMainWin->new_managed_image_from_stock("ct_xml", Gtk::ICON_SIZE_MENU);
+    Gtk::Image* image_xml_pass_protected = pCtMainWin->new_managed_image_from_stock("ct_7zip", Gtk::ICON_SIZE_MENU);
+    Gtk::Image* image_multifile = pCtMainWin->new_managed_image_from_stock("ct_directory", Gtk::ICON_SIZE_MENU);
+
+    auto grid_type = Gtk::manage(new Gtk::Grid{});
+    grid_type->set_row_spacing(2);
+    grid_type->set_column_spacing(4);
+    grid_type->set_row_homogeneous(true);
+
+    grid_type->attach(*image_sqlite_not_protected,          0, 0, 1, 1);
+    grid_type->attach(*image_sqlite_pass_protected,         0, 1, 1, 1);
+    grid_type->attach(*image_xml_not_protected,             0, 2, 1, 1);
+    grid_type->attach(*image_xml_pass_protected,            0, 3, 1, 1);
+    grid_type->attach(*image_multifile,                     0, 4, 1, 1);
+
+    grid_type->attach(radiobutton_sqlite_not_protected,     1, 0, 1, 1);
+    grid_type->attach(radiobutton_sqlite_pass_protected,    1, 1, 1, 1);
+    grid_type->attach(radiobutton_xml_not_protected,        1, 2, 1, 1);
+    grid_type->attach(radiobutton_xml_pass_protected,       1, 3, 1, 1);
+    grid_type->attach(radiobutton_multifile,                1, 4, 1, 1);
 
     Gtk::Frame type_frame(Glib::ustring("<b>")+_("Storage Type")+"</b>");
     dynamic_cast<Gtk::Label*>(type_frame.get_label_widget())->set_use_markup(true);
     type_frame.set_shadow_type(Gtk::SHADOW_NONE);
-    type_frame.add(type_vbox);
+    type_frame.add(*grid_type);
 
     Gtk::Entry entry_passw_1;
     entry_passw_1.set_visibility(false);
@@ -262,6 +278,9 @@ bool CtDialogs::choose_data_storage_dialog(storage_select_args& args)
         else if (args.ctDocType == CtDocType::XML) {
             radiobutton_xml_not_protected.set_active(true);
         }
+        else if (args.ctDocType == CtDocType::MultiFile) {
+            radiobutton_multifile.set_active(true);
+        }
     }
     else if (args.ctDocEncrypt == CtDocEncrypt::True) {
         passw_frame.set_sensitive(true);
@@ -277,7 +296,6 @@ bool CtDialogs::choose_data_storage_dialog(storage_select_args& args)
         passw_frame.set_sensitive(false);
     }
 
-    auto pCtMainWin = args.pCtMainWin;
     auto pCtConfig = pCtMainWin->get_ct_config();
     auto hbox_autosave = Gtk::manage(new Gtk::Box{Gtk::ORIENTATION_HORIZONTAL, 4/*spacing*/});
     auto checkbutton_autosave = Gtk::manage(new Gtk::CheckButton{_("Autosave Every")});
@@ -303,6 +321,8 @@ bool CtDialogs::choose_data_storage_dialog(storage_select_args& args)
 
     Gtk::Box* pContentArea = dialog.get_content_area();
     pContentArea->set_spacing(5);
+    pContentArea->set_margin_left(5);
+    pContentArea->set_margin_right(5);
     pContentArea->pack_start(type_frame);
     pContentArea->pack_start(passw_frame);
     if (args.showAutosaveOptions) {
@@ -337,6 +357,8 @@ bool CtDialogs::choose_data_storage_dialog(storage_select_args& args)
     radiobutton_sqlite_not_protected.signal_toggled().connect(on_radiobutton_savetype_toggled);
     radiobutton_sqlite_pass_protected.signal_toggled().connect(on_radiobutton_savetype_toggled);
     radiobutton_xml_not_protected.signal_toggled().connect(on_radiobutton_savetype_toggled);
+    radiobutton_xml_pass_protected.signal_toggled().connect(on_radiobutton_savetype_toggled);
+    radiobutton_multifile.signal_toggled().connect(on_radiobutton_savetype_toggled);
     dialog.signal_key_press_event().connect(on_key_press_edit_data_storage_type_dialog, false/*call me before other*/);
 
     const int response = dialog.run();
@@ -344,19 +366,25 @@ bool CtDialogs::choose_data_storage_dialog(storage_select_args& args)
 
     bool retVal{Gtk::RESPONSE_ACCEPT == response};
     if (retVal) {
-        args.ctDocType = (radiobutton_xml_not_protected.get_active() || radiobutton_xml_pass_protected.get_active() ?
-                         CtDocType::XML : CtDocType::SQLite);
-        args.ctDocEncrypt = (radiobutton_sqlite_pass_protected.get_active() || radiobutton_xml_pass_protected.get_active() ?
-                            CtDocEncrypt::True : CtDocEncrypt::False);
-        if (CtDocEncrypt::True == args.ctDocEncrypt)
-        {
+        if (radiobutton_multifile.get_active()) {
+            args.ctDocType = CtDocType::MultiFile;
+        }
+        else if (radiobutton_xml_not_protected.get_active() or radiobutton_xml_pass_protected.get_active()) {
+            args.ctDocType = CtDocType::XML;
+        }
+        else {
+            args.ctDocType = CtDocType::SQLite;
+        }
+        args.ctDocEncrypt = radiobutton_sqlite_pass_protected.get_active() or radiobutton_xml_pass_protected.get_active() ?
+                            CtDocEncrypt::True : CtDocEncrypt::False;
+        if (CtDocEncrypt::True == args.ctDocEncrypt) {
             args.password = entry_passw_1.get_text();
             if (args.password.empty()) {
-                error_dialog(_("The Password Fields Must be Filled."), *args.pCtMainWin);
+                error_dialog(_("The Password Fields Must be Filled."), *pCtMainWin);
                 retVal = false;
             }
             else if (args.password != entry_passw_2.get_text()) {
-                error_dialog(_("The Two Inserted Passwords Do Not Match."), *args.pCtMainWin);
+                error_dialog(_("The Two Inserted Passwords Do Not Match."), *pCtMainWin);
                 retVal = false;
             }
         }
@@ -516,7 +544,7 @@ MA 02110-1301, USA.
 )STR"));
     dialog.set_website("https://www.giuspen.net/cherrytree/");
     dialog.set_authors({"Giuseppe Penone <giuspen@gmail.com>", "Evgenii Gurianov <https://github.com/txe>"});
-    dialog.set_artists({"Ugo Yak <https://www.instagram.com/ugoyak.art/>", "OCAL <http://www.openclipart.org/>", "Zeltak <zeltak@gmail.com>", "Angelo Penone <angelo.penone@gmail.com>"});
+    dialog.set_artists({"Ugo Yak <https://www.instagram.com/ugoyak.art/>", "SVG Repo <https://www.svgrepo.com/>", "OCAL <http://www.openclipart.org/>", "Zeltak <zeltak@gmail.com>", "Angelo Penone <angelo.penone@gmail.com>"});
     dialog.set_translator_credits(Glib::ustring{} +
  _("Arabic")+" (ar) Mohamed Milodi <milodi500@gmail.com>"+CtConst::CHAR_NEWLINE+
  _("Armenian")+" (hy) Seda Stamboltsyan <sedastam@yandex.com>"+CtConst::CHAR_NEWLINE+
@@ -538,9 +566,9 @@ MA 02110-1301, USA.
  _("Kazakh (Latin)")+" (kk_LA) Viktor Polyanskiy <camilot55@yandex.ru>"+CtConst::CHAR_NEWLINE+
  _("Korean")+" (ko) Sean Lee <icarusean@gmail.com>"+CtConst::CHAR_NEWLINE+
  _("Lithuanian")+" (lt) Zygis <zygimantus@gmail.com>"+CtConst::CHAR_NEWLINE+
- _("Polish")+" (pl) Daniel Napora <napcok@gmail.com>"+CtConst::CHAR_NEWLINE+
+ _("Polish")+" (pl) Mariusz Gasperaniec <margsp@vivaldi.net>"+CtConst::CHAR_NEWLINE+
  _("Portuguese")+" (pt) Rui Santos <ruiagfsantos@mail.com>"+CtConst::CHAR_NEWLINE+
- _("Portuguese Brazil")+" (pt_BR) Rui Santos <ruiagfsantos@mail.com>"+CtConst::CHAR_NEWLINE+
+ _("Portuguese Brazil")+" (pt_BR) Raysa Dutra <raysadutra.dev@gmail.com>"+CtConst::CHAR_NEWLINE+
  _("Romanian")+" (ro) Tudor Sprinceana <tudorsprinceana@yahoo.com>"+CtConst::CHAR_NEWLINE+
  _("Russian")+" (ru) Viktor Polyanskiy <camilot55@yandex.ru>"+CtConst::CHAR_NEWLINE+
  _("Slovenian")+" (sl) Erik Lovrič <erik.lovric@gmail.com>"+CtConst::CHAR_NEWLINE+
