@@ -242,7 +242,7 @@ std::string CtMainWin::get_code_icon_name(std::string code_type)
             return iconPair.second;
         }
     }
-    return CtConst::NODE_CUSTOM_ICONS.at(CtConst::NODE_ICON_CODE_ID);
+    return CtStockIcon::at(CtConst::NODE_ICON_CODE_ID);
 }
 
 Gtk::Image* CtMainWin::new_managed_image_from_stock(const std::string& stockImage, Gtk::BuiltinIconSize size)
@@ -555,14 +555,14 @@ void CtMainWin::menu_set_bookmark_menu_items()
 void CtMainWin::menu_set_items_recent_documents()
 {
     sigc::slot<void, const std::string&> recent_doc_open_action = [&](const std::string& filepath){
-        if (Glib::file_test(filepath, Glib::FILE_TEST_IS_REGULAR)) {
+        if (Glib::file_test(filepath, Glib::FILE_TEST_EXISTS)) {
             if (file_open(filepath, ""/*node*/, ""/*anchor*/)) {
                 _pCtConfig->recentDocsFilepaths.move_or_push_front(fs_canonicalize_filename(filepath));
                 menu_set_items_recent_documents();
             }
         }
         else {
-            g_autofree gchar* title = g_strdup_printf(_("The Document %s was Not Found"), str::xml_escape(filepath).c_str());
+            g_autofree gchar* title = g_strdup_printf(_("The Path %s does Not Exist"), str::xml_escape(filepath).c_str());
             CtDialogs::error_dialog(Glib::ustring{title}, *this);
             _pCtConfig->recentDocsFilepaths.move_or_push_back(fs_canonicalize_filename(filepath));
             menu_set_items_recent_documents();
@@ -650,11 +650,10 @@ void CtMainWin::config_switch_tree_side()
 void CtMainWin::_zoom_tree(bool is_increase)
 {
     Glib::RefPtr<Gtk::StyleContext> context = _uCtTreeview->get_style_context();
-    Pango::FontDescription fontDesc = context->get_font(context->get_state());
+    const Pango::FontDescription fontDesc = context->get_font(context->get_state());
     int size = fontDesc.get_size() / Pango::SCALE + (is_increase ? 1 : -1);
     if (size < 6) size = 6;
-    fontDesc.set_size(size * Pango::SCALE);
-    _pCtConfig->treeFont = CtFontUtil::get_font_str(fontDesc);
+    _pCtConfig->treeFont = CtFontUtil::get_font_str(CtFontUtil::get_font_family(_pCtConfig->treeFont), size);
     signal_app_apply_for_each_window([](CtMainWin* win) { win->update_theme(); win->window_header_update(); });
 }
 
