@@ -34,6 +34,7 @@
 #include <type_traits>
 #include <glibmm/ustring.h>
 #include <gtksourceviewmm/buffer.h>
+#include "ct_const.h"
 
 namespace fs {
 class path;
@@ -41,7 +42,7 @@ class path;
 
 enum class CtYesNoCancel { Yes, No, Cancel };
 
-enum class CtDocType { None, XML, SQLite };
+enum class CtDocType { None, XML, SQLite, MultiFile };
 
 enum class CtDocEncrypt { None, True, False };
 
@@ -53,7 +54,7 @@ enum class CtSaveNeededUpdType { None, nbuf, npro, ndel, book };
 
 enum class CtXmlNodeType { None, RichText, EncodedPng, Table, CodeBox };
 
-enum class CtExporting { NONE, SELECTED_TEXT, CURRENT_NODE, CURRENT_NODE_AND_SUBNODES, ALL_TREE };
+enum class CtExporting { NONESAVE, NONESAVEAS, SELECTED_TEXT, CURRENT_NODE, CURRENT_NODE_AND_SUBNODES, ALL_TREE };
 
 enum class CtListType { None, Todo, Bullet, Number };
 
@@ -62,7 +63,10 @@ enum class CtRestoreExpColl : int { FROM_STR=0, ALL_EXP=1, ALL_COLL=2 };
 class CtCodebox;
 class CtMainWin;
 using CtPairCodeboxMainWin = std::pair<CtCodebox*, CtMainWin*>;
-
+namespace xmlpp {
+class Document;
+}
+using CtDelayedTextBufferMap = std::unordered_map<gint64, std::shared_ptr<xmlpp::Document>>;
 using CtCurrAttributesMap = std::unordered_map<std::string_view, std::string>;
 
 struct CtLinkEntry
@@ -236,7 +240,7 @@ private:
 
 struct CtStorageNodeState
 {
-    bool upd{false};
+    bool is_update_of_existing{false};
     bool prop{false};
     bool buff{false};
     bool hier{false};
@@ -247,7 +251,18 @@ struct CtStorageSyncPending
     bool                                           fix_db_tables{true};
     bool                                           bookmarks_to_write{false};
     std::unordered_map<gint64, CtStorageNodeState> nodes_to_write_dict;
-    std::set<gint64>                               nodes_to_rm_set;
+    std::unordered_set<gint64>                     nodes_to_rm_set;
+};
+
+enum class CtBackupType { None, SingleFile, MultiFile };
+struct CtBackupEncryptData
+{
+    CtBackupType backupType;
+    bool needEncrypt;
+    std::string main_backup;
+    std::string file_path;
+    std::string password;
+    std::string extracted_copy;
 };
 
 struct CtNodeData;
@@ -267,7 +282,7 @@ public:
     virtual bool save_treestore(const fs::path& file_path,
                                 const CtStorageSyncPending& syncPending,
                                 Glib::ustring& error,
-                                const CtExporting exporting = CtExporting::NONE,
+                                const CtExporting exporting,
                                 const int start_offset = 0,
                                 const int end_offset = -1) = 0;
     virtual void vacuum() = 0;
@@ -283,6 +298,17 @@ protected:
     bool _isDryRun{false};
 };
 
+struct CtStockIcon
+{
+    static const gchar* at(const size_t i) {
+        if (i < CtConst::_NODE_CUSTOM_ICONS.size()) {
+            return CtConst::_NODE_CUSTOM_ICONS.at(i);
+        }
+        return CtConst::_NODE_CUSTOM_ICONS.at(CtConst::NODE_ICON_NO_ICON_ID);
+    }
+    static size_t size() { return CtConst::_NODE_CUSTOM_ICONS.size(); }
+};
+
 struct CtExportOptions
 {
     bool include_node_name{true};
